<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <location filename="../cssedit.ui" line="16"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="30"/>
        <source>Element</source>
        <translation>Elemento</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="37"/>
        <source>Foreground</source>
        <translation>Primo piano</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="44"/>
        <source>Background</source>
        <translation>Sfondo</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="51"/>
        <source>Select element</source>
        <translation>Seleziona elementi</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="68"/>
        <source>Click to select color</source>
        <translation>Click per selezionare il colore</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="71"/>
        <source>#000000</source>
        <translation>#000000</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="78"/>
        <source>Font</source>
        <translation>Carattere</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="85"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="92"/>
        <source>Select font</source>
        <translation>Seleziona carattere</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="99"/>
        <source>Select font size</source>
        <translation>Seleziona dimensione carattere</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="102"/>
        <source>pt</source>
        <translation>pt</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="127"/>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="130"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="147"/>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="150"/>
        <source>I</source>
        <translation>I</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="167"/>
        <source>Underline</source>
        <translation>Sottolineato</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="170"/>
        <source>U</source>
        <translation>U</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <location filename="../dictbrowser.cpp" line="72"/>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation>La parola &lt;b&gt;%1&lt;/b&gt; non è stata trovata.</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <location filename="../dictwidget.cpp" line="114"/>
        <source>Save translation</source>
        <translation>Salva la traduzione</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="135"/>
        <source>HTML files (*.html, *.htm)</source>
        <translation>File HTML (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="124"/>
        <source>Text files (*.txt)</source>
        <translation>File di testo (*.txt)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="130"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="131"/>
        <source>Cannot save translation as %1</source>
        <translation>Non posso salvare la traduzione come %1</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="75"/>
        <source>Go to &amp;previous translation</source>
        <translation>Vai alla traduzione &amp;precedente</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="80"/>
        <source>Go to &amp;next translation</source>
        <translation>Vai alla traduzione s&amp;uccessiva</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="85"/>
        <source>&amp;Save to file</source>
        <translation>&amp;Salva come</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="91"/>
        <source>Speak &amp;word</source>
        <translation>Pronuncia f&amp;rase</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="88"/>
        <source>Prin&amp;t translation</source>
        <translation>S&amp;tampa traduzione</translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>About QStarDict</source>
        <translation>Informazioni su QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Versione Qt di StarDict&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Copyright (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation>Copyright  (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="13"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>%1 - QStarDict</source>
        <translation>%1 - QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Clear the search box</source>
        <translation>Cancella la ricerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Fuzzy query</source>
        <translation>Fuzzy query</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Words list</source>
        <translation>Lista delle Frasi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>&amp;About</source>
        <translation>I&amp;nformazioni su</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;Configure QStarDict</source>
        <translation>C&amp;onfigura QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>&amp;Scan</source>
        <translation>&amp;Cerca</translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Enabled</source>
        <translation>Attivato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Plugin</source>
        <translation>Estensione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="261"/>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation>Informazione sul dizionario &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="279"/>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Nome:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="263"/>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Estensione:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>unknown</source>
        <translation>ignoto</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="283"/>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Descrizione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="278"/>
        <source>Information about %1 plugin</source>
        <translation>Informazione sull&apos;estensione %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="280"/>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Versione:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Autori:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;br&gt;</source>
        <translation>&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Puoi cercare parole simili:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>yes</source>
        <translation>si</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>no</source>
        <translation>no</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>QStarDict Settings</source>
        <translation>Impostazioni QStarDict</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="16"/>
        <source>Show information about dictionary</source>
        <translation>Mostra informazioni sul dizionario</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Global settings</source>
        <translation>Impostazioni globali</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Instant search</source>
        <translation>Ricerca istantanea</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Pronounce words using this command:</source>
        <translation>Pronuncia le parole usando questo comando:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation>Inserisci il comando per il programma di pronuncia.&lt;br&gt;Se il comando contiene &quot;%s&quot; la parola verrà sostituita, altrimenti la parola sarà scritta nello stdin del processo di pronuncia.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Dictionaries</source>
        <translation>Dizionari</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="147"/>
        <source>Move up</source>
        <translation>Sposta in su</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Move down</source>
        <translation>Sposta in giù</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Down</source>
        <translation>Giù</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Show info</source>
        <translation>Mostra informazioni</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>Plugins</source>
        <translation>Estensioni</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <source>Show information about plugin</source>
        <translation>Mostra informazioni sull&apos;estensione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="237"/>
        <source>Info</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="247"/>
        <source>Configure plugin</source>
        <translation>Configura estensione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>Popup window</source>
        <translation>Finestra di popup</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="303"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Pronounce the word</source>
        <translation>Pronuncia la parola</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Timeout before hide after mouse over</source>
        <translation>Tempo di scomparsa dopo aver mosso il mouse</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="377"/>
        <source>Don&apos;t hide</source>
        <translation>Non nascondere</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source> sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="424"/>
        <source>Show only if modifier pressed</source>
        <translation>Mostra solo se si preme</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="435"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="440"/>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="445"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="450"/>
        <source>Win</source>
        <translation>Win</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="460"/>
        <source>Scan selection</source>
        <translation>Cerca selezione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="470"/>
        <source>Show if word not found</source>
        <translation>Mostra se la parola non viene trovata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="644"/>
        <source>Apperance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="521"/>
        <source>Opacity</source>
        <translation>Opacità</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="528"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="566"/>
        <source>Default width</source>
        <translation>Ampiezza di default</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="605"/>
        <source>Default height</source>
        <translation>Altezza di default</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="264"/>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Autore:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Conto parole:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>All translation</source>
        <translation>Tutta la traduzione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Dictionary name</source>
        <translation>Nome del dizionario</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Explanation</source>
        <translation>Spiegazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>Abbreviation</source>
        <translation>Abbreviazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>Example</source>
        <translation>Esempio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Transcription</source>
        <translation>Trascrizione</translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="36"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="37"/>
        <source>&amp;Scan</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="47"/>
        <source>&amp;Configure QStarDict</source>
        <translation>&amp;Configura QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="50"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>QStarDict: scanning is %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
